@@ -15,7 +15,7 @@
 #' @export
 clean_va <- function(x, quali = c("nlp", "lp", "hm", "cf"), message = TRUE) {
   originalNA <- is.na(x)
-  x_tidied <- tolower(tidyNA(x))
+  x_tidied <- tidyNA_low(x)
   x_tidied <- gsub("\\s", "", x_tidied)
 
   # unifying nlp/npl etc
@@ -76,3 +76,56 @@ convertQuali <- function(x, to_class){
   }
   x
 }
+
+
+#' Tidy NA entries to actual NA values
+#' @name tidyNA
+#' @description Creates tidy NA entries - NA equivalent strings are tidied to
+#'   actual NA values
+#' @param x Vector
+#' @param ... passed to [isNAstring]
+#' @return character vector
+#' @examples
+#' x <- c("a", "   ", ".", "-", "NULL")
+#' tidyNA(x)
+#'
+#' # in addition to the default strings, a new string can be added
+#' tidyNA(x, string = "a")
+#'
+#' # or just remove the strings you want
+#' tidyNA(x, string = "a", defaultstrings = FALSE)
+#' @export
+#'
+tidyNA <- function(x, ...){
+  y <- tolower(x)
+  x[isNAstring(y, ...)] <- NA_character_
+  x
+}
+
+#' @rdname tidyNA
+#' @details tidyNA_low is an internal function used for VA cleaning
+#'   returning a lower case vector.
+#' @keywords internals
+tidyNA_low <- function(x, ...){
+  y <- tolower(x)
+  y[isNAstring(y, ...)] <- NA_character_
+  y
+}
+
+#' @rdname tidyNA
+#' @param string vector of full strings to be replaced by NA
+#' @param defaultstrings by default (TRUE), the following strings will be replaced by
+#'   NA values: c("\\.+", "", "\\s+", "n/a", "na", "null", "^-$").
+#' @keywords internal
+isNAstring <- function(x, string = NULL, defaultstrings = TRUE) {
+  if(defaultstrings){
+    full <- c(c("\\.+", "", "\\s+", "n/a", "na", "null", "^-$"), string)
+  } else {
+    full <- string
+  }
+  fullpaste <- paste0("^", paste(full, collapse = "$|^"), "$")
+  isNA <- grepl(fullpaste, x)
+  isNA
+}
+
+
